## Product details

DAYBETTER boasts self-developed Bluetooth LED lights strip,let indirect lighting brighten your life, create more color for the room. Our LED light strips can fill your room with rich color, brighten a dim room to help get things done or glow softly to set a mood by our color change LED lights. More LED lights of different styles are available in DAYBETTER shop:
www.walmart.com/daybetter

New arrival:

6 inch Ultra-Thin LED Recessed Ceiling Light👈

Christmas Net Lights Outdoor👈

Christmas Pathway Lights👈

100FT G40 Outdoor String Lights for Outside 31.99$ 👈

Meteor Shower Lights Outdoor👈

Similar item to consider:

RGBW Wi-Fi Smart Led Bulbs 6Pack 21.99$ 👈

100ft LED strip lights for extensive coverage
App control for easy customization
5050 RGB LEDs for vibrant color display
Music sync feature for dynamic lighting
Ideal for bedroom and party decorations
Remote control included for convenience
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Color type
Multicolor, Red, Green
Product net content parent
100 Foot
Light bulb color
RGB
Number of lights
360
More details
## Warranty

Warranty information
One year warranty

Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
More details
